---
feature_story: FS_16_07_78_84
feature_title: conf_dir_priority
feature_status: TODO
---

There is only one configuration directory used as the source.
It is selected based on priority:

*   Highest priority: `ARGRELAY_CONF_BASE_DIR` env var: `${ARGRELAY_CONF_BASE_DIR}/*`

    If `ARGRELAY_CONF_BASE_DIR` is defined, config files will be looked up in, for example:

    TODO: remove `.argrelay.conf.d` from the path:

    ```sh
    ls ${ARGRELAY_CONF_BASE_DIR}/python_conf.bash
    ls ${ARGRELAY_CONF_BASE_DIR}/argrelay_rc_conf.bash
    ls ${ARGRELAY_CONF_BASE_DIR}/argrelay.server.yaml
    ls ${ARGRELAY_CONF_BASE_DIR}/argrelay.client.json
    # ...
    ```

*   User home dir (or `~/`): `~/.argrelay.conf.d/*`

    For example:

    ```sh
    ls ~/.argrelay.conf.d/python_conf.bash
    ls ~/.argrelay.conf.d/argrelay_rc_conf.bash
    ls ~/.argrelay.conf.d/argrelay.server.yaml
    ls ~/.argrelay.conf.d/argrelay.client.json
    # ...
    ```

*   Lowest priority: `argrelay_dir` (or `@/`): `@/conf/*`

    See also `FS_29_54_67_86.dir_structure.md`

    Project directory paths, for example:

    ```sh
    ls conf/python_conf.bash
    ls conf/argrelay_rc_conf.bash
    ls conf/argrelay.server.yaml
    ls conf/argrelay.client.json
    # ...
    ```
